@@ -58,8 +58,8 @@ class CookieConsentLogAdmin(admin.ModelAdmin):
     def has_add_permission(self, request):
         return False
 
-    def has_change_permission(self, request, obj=None):
-        return False
+    # def has_change_permission(self, request, obj=None):
+    #     return False
 
     def has_delete_permission(self, request, obj=None):
         return False
